*Impute complete consumption

set more off
set seed 23081985 
set sortseed 11041985

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

*number of imputations
local n = 100

*prepare household member dataset
use "${gsdData}/1-CleanOutput/hhm.dta", clear
gen nchild = age<15 if !missing(age)
gen nsenior = age>64 if !missing(age)
gen hhsex = gender if ishead
gen hhempl = active_12m if ishead
gen hhedu = hhm_edu_ever if ishead
collapse (sum) nchild nsenior (min) hhsex hhempl hhedu (count) hhsize = hhmid, by(strata ea block hh)
gen pchild = nchild / hhsize
gen psenior = nsenior / hhsize
drop nchild nsenior
save "${gsdData}/1-CleanTemp/hhm-hh.dta", replace

*prepare household dataset
use "${gsdData}/1-CleanInput/hh.dta", clear
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hh_fcons.dta", keepusing(cons* opt_mod) nogen assert(match) keep(match)
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hh_nfcons.dta", keepusing(cons*) nogen assert(match) keep(match)
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hh_durables.dta", keepusing(cons_d) nogen assert(match)
merge 1:1 strata ea block hh using "${gsdData}/1-CleanTemp/hhm-hh.dta", keepusing(pchild psenior hhsex hhempl hhedu hhsize) nogen assert(match)

*ensure core food consumption
*assert cons_f0 > 0 | missing(cons_f0) 
foreach v of var cons_f1 cons_f2 cons_f3 cons_f4 cons_nf? cons_d {
	replace `v' = .c if cons_f0 == 0
}
*require positive food core consumption (otherwise, we assume data is missing)
drop if missing(cons_f0)

*prepare model variables
replace hhempl = 0 if missing(hhempl)
replace hhsex = 1 if missing(hhsex)
replace hhedu = 0 if missing(hhedu)
*clean variables for model
recode house_type (1/2=1 "Apartament") (3/4=2 "House") (5/6=3 "Hut") (7/max=4 "Other") (missing=4), gen(hh_type) label(lhh_type)
recode drink_water (1/3=1 "Piped") (4=2 "Tap") (5/9=3 "Tap or well") (10/max=4 "Delivered") (missing=4), gen(hh_drinkwater) label(lhh_drinkwater)
recode floor_material (1/2=1 "Solid") (3=2 "Mud") (4/max=3 "Wood/other") (missing=3), gen(hh_floor) label(lhh_floor)
recode house_ownership (1=1 "Rent") (2=2 "Own") (3/max=3 "Occupation") (missing=3), gen(hh_ownership) label(lhh_ownership)
recode hunger (1=0 "Never") (2=1 "Rarely") (3/max=2 "Often") (missing=2), gen(hh_hunger) label(lhh_hunger)
recode remit12m (missing=0)
*prepare smaller dataset
drop weight 
ren weight_cons weight
keep team strata ea block hh hhsize weight opt_mod pchild psenior hhempl hhsex hhedu hh_type hh_drinkwater hh_floor hh_ownership hh_hunger remit12m cons_f? cons_nf? cons_d astrata type
ren type hh_ptype
*prepare consumption variables
*make sure missing modules have missing consumption
forvalues i = 1/4 {
	replace cons_f`i' = . if opt_mod!=`i'
	replace cons_nf`i' = . if opt_mod!=`i'
}
*adjust to per capita per day 
forvalues i = 0/4 {
	replace cons_f`i' = cons_f`i' / hhsize / 7
	replace cons_nf`i' = cons_nf`i' / hhsize / 7
	label var cons_f`i' "Collected food consumption mod `i' pc pd curr USD"
	label var cons_nf`i' "Collected non-food consumption mod `i' pc pd curr USD"
	gen mi_cons_f`i' = cons_f`i'
	gen mi_cons_nf`i' = cons_nf`i'
	label var mi_cons_f`i' "Imputed food consumption mod `i' pc pd curr USD"
	label var mi_cons_nf`i' "Imputed non-food consumption mod `i' pc pd curr USD"
}
replace cons_d = cons_d / hhsize / 7
gen mi_cons_d = cons_d
label var cons_d "Consumption flow of durables pc pd curr USD"
label var mi_cons_d "Imputed consumption flow of durables pc pd curr USD"
*create some aggregates
egen cons_f =  rowtotal(mi_cons_f?)
egen cons_nf =  rowtotal(mi_cons_nf?)
label var cons_f "Collected food consumption pc pd curr USD"
label var cons_nf "Collected non-food consumption pc pd curr USD"
xtile pmi_cons_f0 = mi_cons_f0 [pweight=weight], nquantiles(4)
xtile pmi_cons_nf0 = mi_cons_nf0 [pweight=weight], nquantiles(4)
xtile pmi_cons_d = mi_cons_d [pweight=weight], nquantiles(4)
*build model
local model = "hhsize pchild psenior i.hhsex i.hhempl hhedu i.hh_type i.hh_drinkwater i.hh_floor i.hh_ownership i.hh_hunger i.team i.hh_ptype i.remit12m"
local model = "i.pmi_cons_f0 i.pmi_cons_nf0 i.pmi_cons_d `model'"
*create core consumption for comparison
save "${gsdData}/1-CleanTemp/mi-pre.dta", replace

*Run imputation
use "${gsdData}/1-CleanTemp/mi-pre.dta", clear
*MI
mi set wide
mi register imputed mi_cons_f1 mi_cons_f2 mi_cons_f3 mi_cons_f4 mi_cons_nf1 mi_cons_nf2 mi_cons_nf3 mi_cons_nf4
mi register regular hh* mi_cons_f0 mi_cons_nf0 mi_cons_d
*Multi-variate normal imputation using MCMC 
set seed 23081985 
mi impute mvn mi_cons_f1 mi_cons_f2 mi_cons_f3 mi_cons_f4 mi_cons_nf1 mi_cons_nf2 mi_cons_nf3 mi_cons_nf4 = `model', add(`n') burnin(1000)
save "${gsdTemp}/mi.dta", replace

*scale to per day and per capita
use "${gsdTemp}/mi.dta", clear
*prepare variables to merge
merge m:1 astrata using "${gsdData}/1-CleanTemp/food-deflator.dta", nogen assert(match) keep(match)
gen hhweight = weight * hhsize
*iterate over modules
foreach cat in f nf {
	forvalues i=1/4 {
		*need to take floor to make sure rounding does not result in negative averages
		egen double xtag`cat'`i' = rowtotal(_*_mi_cons_`cat'`i')
		forvalues j=1/`n' {
			*scale up to get average being zero (without losing the variance)
			replace _`j'_mi_cons_`cat'`i' = _`j'_mi_cons_`cat'`i' - floor(xtag`cat'`i' /`n'*10^5)/10^5 if xtag`cat'`i'<0
		}
	}
}
drop xtag*
*create sub-aggregateswe
mi passive: egen mi_cons_f = rowtotal(mi_cons_f?)
mi passive: egen mi_cons_nf = rowtotal(mi_cons_nf?)
label var mi_cons_f "Imputed food consumption pc pd curr USD"
label var mi_cons_nf "Imputed non-food consumption pc pd curr USD"
*create aggregates
gen tc_core = (cons_f0 + cons_nf0)/deflator + cons_d
egen pre_tc_summ =rowtotal(cons_f0 cons_f1 cons_f2 cons_f3 cons_f4 cons_nf0 cons_nf1 cons_nf2 cons_nf3 cons_nf4) 
gen tc_summ=pre_tc_summ / deflator + cons_d
mi passive: gen tc_imp = (mi_cons_f + mi_cons_nf) / deflator + mi_cons_d
label var tc_core "Total real Feb 2016 consumption based on core pc pd curr USD"
label var tc_summ "Total real Feb 2016 consumption based on summing pc pd curr USD"
label var tc_imp "Total real Feb 2016 consumption based on imputation pc pd curr USD"
*add exchange rate
gen zone = 3
merge m:1 zone using "${gsdData}/1-CleanInput/HFS Exchange Rate Survey.dta", nogen keepusing(global_er) assert(match using) keep(match)
merge m:1 zone using "${gsdData}/1-CleanTemp/inflation.dta", nogen keepusing(gg) assert(match using) keep(match)
drop zone
*poverty line 1.90 USD in USD PPP (2011) using private consumption PPP conversion factor
*in 2011: 1 PPP USD was worth 10,731 SSh PPP
*Inflation from 2011 to Feb 2016: 1.684297
*10,731 * 1.684297 = 18,074.19 SSh (2016) could buy 1 PPP 2011 USD
*1.90 PPP 2011 USD = 18,074.19 * 1.90 = 34,340.96 SSh (2016)
*In current (2016) USD: 34,340.96 / global_er
gen plinePPP = 10731 * gg * 1.9 / global_er
gen plinePPP125 = 10731 * gg * 1.25 / global_er
label var plinePPP "2011 PPP 1.90 USD Poverty Line in 2016 USD Somalia"
label var plinePPP125 "2011 PPP 1.25 USD Poverty Line in 2016 USD Somalia"
*calculate poverty
mi passive: gen poorPPP = tc_imp < plinePPP if !missing(tc_imp)
mi passive: gen poorPPP125 = tc_imp < plinePPP125 if !missing(tc_imp)
mi svyset ea [pweight=hhweight], strata(strata)
label var poorPPP "Below 2011 PPP poverty line"
label define lpoorPPP 0 "Non-poor" 1 "Poor"
label values poorPPP lpoorPPP
drop global_er gg

*include additional weights considering a different distribution of EAs w/zero prob of sample selection
*obtain deciles and quantiles 
rename weight weight_pre_cons
levelsof astrata, local(group) 
qui foreach i of local group {
	xtile deciles`i'= tc_imp if astrata==`i', nquantiles(10) 
	xtile quantiles`i'=tc_imp if astrata==`i', nquantiles(4) 
}
*obtain a dummy variable in long format to identify hhs in the bottom of the distribution
gen dum_bottom10=1 if deciles3==1 
gen dum_bottom25=1 if quantiles3==1
gen dum_bottom50=1 if quantiles3==1 | quantiles3==2
gen dum_bottom75=1 if quantiles3==1 | quantiles3==2 | quantiles3==3
qui foreach stratum in "11" "12" "13" "14" "15" "21" "22"  {
	replace dum_bottom10=1 if deciles`stratum'==1 
	replace dum_bottom25=1 if quantiles`stratum'==1
	replace dum_bottom50=1 if quantiles`stratum'==1 | quantiles`stratum'==2
	replace dum_bottom75=1 if quantiles`stratum'==1 | quantiles`stratum'==2 | quantiles`stratum'==3
}
drop deciles* quantiles*
*obtain necessary variables to scale the weights and obtain weights 
merge m:1 astrata using "${gsdData}/1-CleanInput/households_pess.dta", nogen keep(match)
rename hhs_tot_astrata total_hhs
foreach num in "10" "25" "50" "75" { 
	bys astrata: egen x`num'=sum(weight_pre_cons) if dum_bottom`num'==1
	bys astrata: egen total_bottom`num'=max(x`num')
	bys astrata: egen y`num'=sum(weight_pre_cons) if dum_bottom`num'>=.
	bys astrata: egen total_bottom`num'_rest=max(y`num') 
	bys astrata: gen factor_p`num'=(total_hhs-total_bottom`num'_rest)/total_bottom`num'
	gen weight_`num'=weight_pre_cons*factor_p`num' if dum_bottom`num'==1 & factor_p`num'>0
	replace weight_`num'=weight_pre_cons if dum_bottom`num'>=.  | factor_p`num'<0
}

*check astrata for which our total hhs (accessible GPS) are greater than PESS regions (hence adjusment is against hhs in the bottom 25% or negative weights)
*thus adjust weight_25 and downscale the weights uniformly 
*for negative weights 
bys astrata: egen total_master=sum(weight_25) 
gen excedent= total_master - total_hhs if astrata==21 | astrata==22 
gen share=weight_25/total_master
replace weight_25=share*total_hhs if astrata==21 | astrata==22  
drop excedent share
*for incorrect adjustment aginst hhs in the bottom 25%
bys astrata: egen total_master_gps=sum(weight_pre_cons) 
gen excedent= total_master_gps - total_hhs if astrata==13  | astrata==14
gen share=weight_pre_cons/total_master_gps
replace weight_25=share*total_hhs if astrata==13  | astrata==14
*include the scale of IDPs considering a uniform allocation 
replace weight_25=weight_pre_cons if astrata==3
bys astrata: egen hhs_current=sum(weight_25) if astrata==3
gen factor=total_hhs/hhs_current if astrata==3
replace weight_25=weight_25*factor if astrata==3
*check to make sure the total is still the same
bys astrata: egen check=sum(weight_25)     
assert round(check)==round(total_hhs)
rename weight_25 weight_cons
label var weight_cons "Household weights (adjusted bottom 25% hhs)"
order weight_cons, after(hh)
drop x* y* total_bottom* factor factor* hhs_current
drop total_hhs check* weight_10 weight_50 weight_75 hhweight dum_* weight_pre_cons

*estimate poverty figures with the final weights 
gen hhweight = weight_cons * hhsize
mi svyset ea [pweight=hhweight], strata(strata)
mi estimate: mean poorPPP [pweight=hhweight]
mi estimate: mean poorPPP125 [pweight=hhweight]
save "${gsdData}/1-CleanTemp/mi-analysis.dta", replace

*extract data
use "${gsdData}/1-CleanTemp/mi-analysis.dta", clear
forvalues i = 1/`n' {
	use "${gsdData}/1-CleanTemp/mi-analysis.dta", clear
	mi extract `i', clear	
	gen mi = `i'
	save "${gsdTemp}/mi_`i'.dta", replace
}
*append
clear
forvalues i = 1/`n' {
	append using "${gsdTemp}/mi_`i'.dta"
}
save "${gsdTemp}/mi-extract.dta", replace

*analysis on extract dataset
use "${gsdTemp}/mi-extract.dta", clear
fastgini tc_imp [pweight=hhweight]
collapse (mean) tc_* mi_cons_f? mi_cons_nf? mi_cons_d (mean) poorPPP_prob = poorPPP, by(team strata ea block hh astrata hhsize weight weight_* hhweight opt_mod plinePPP)
svyset ea [pweight=hhweight], strata(strata)
mean poorPPP_prob [pweight=hhweight]
gen poorPPP = poorPPP_prob > .55
mean poorPPP [pweight=hhweight]
label var tc_core "Total real Feb 2016 consumption based on core pc pd curr USD"
label var tc_summ "Total real Feb 2016 consumption based on summing pc pd curr USD"
label var tc_imp "Total real Feb 2016 consumption based on imputation pc pd curr USD"
label var poorPPP_prob "Probability being below 2011 PPP poverty line"
label var poorPPP "Being below 2011 PPP poverty line"
forvalues i = 0/4 {
	label var mi_cons_f`i' "Food module `i' consumption pc pd curr USD"
	label var mi_cons_nf`i' "Non-Food module `i' consumption pc pd curr USD"
}
label var mi_cons_d "Durable consumption pc pd curr USD"
label var astrata "Analytical strata"
save "${gsdData}/1-CleanTemp/hhq-poverty.dta", replace
